pub struct BuildRepo {
pub repo: String,
}Expand description
Builds the target repo, using the attached builder. Response: Update.
Note. Repo must have builder attached at builder_id.
- Spawns the target builder instance (For AWS type. For Server type, just use CloneRepo).
- Clones the repo on the builder using
git clone https://{$token?}@github.com/${repo} -b ${branch}. The token will only be used if a github account is specified, and must be declared in the periphery configuration on the builder instance. - If
on_cloneandon_pullare specified, they will be executed.on_clonewill be executed beforeon_pull.
Fields
repo: StringId or name