pub struct GetCoreInfoResponse {
pub title: String,
pub monitoring_interval: Timelength,
pub webhook_base_url: String,
pub transparent_mode: bool,
pub ui_write_disabled: bool,
pub github_webhook_owners: Vec<String>,
}Expand description
Response for GetCoreInfo.
Fields
title: StringThe title assigned to this core api.
monitoring_interval: TimelengthThe monitoring interval of this core api.
webhook_base_url: StringThe webhook base url.
transparent_mode: boolWhether transparent mode is enabled, which gives all users read access to all resources.
ui_write_disabled: boolWhether UI write access should be disabled
github_webhook_owners: Vec<String>The repo owners for which github webhook management api is available