pub struct BuildConfig {Show 23 fields
pub builder_id: String,
pub version: Version,
pub auto_increment_version: bool,
pub image_name: String,
pub image_tag: String,
pub git_provider: String,
pub git_https: bool,
pub git_account: String,
pub repo: String,
pub branch: String,
pub commit: String,
pub webhook_enabled: bool,
pub webhook_secret: String,
pub pre_build: SystemCommand,
pub image_registry: ImageRegistry,
pub build_path: String,
pub dockerfile_path: String,
pub skip_secret_interp: bool,
pub use_buildx: bool,
pub extra_args: Vec<String>,
pub build_args: Vec<EnvironmentVar>,
pub secret_args: Vec<EnvironmentVar>,
pub labels: Vec<EnvironmentVar>,
}Expand description
The build configuration.
Fields
builder_id: StringWhich builder is used to build the image.
version: VersionThe current version of the build.
auto_increment_version: boolWhether to automatically increment the patch on every build.
Default is true
image_name: StringAn alternate name for the image pushed to the repository. If this is empty, it will use the build name.
Can be used in conjunction with image_tag to direct multiple builds
with different configs to push to the same image registry, under different,
independantly versioned tags.
image_tag: StringAn extra tag put before the build version, for the image pushed to the repository.
Eg. in image tag of aarch64 would push to mbecker20/monitor_core:aarch64-1.13.2.
If this is empty, the image tag will just be the build version.
Can be used in conjunction with image_name to direct multiple builds
with different configs to push to the same image registry, under different,
independantly versioned tags.
git_provider: StringThe git provider domain. Default: github.com
git_https: boolWhether to use https to clone the repo (versus http). Default: true
Note. Monitor does not currently support cloning repos via ssh.
git_account: StringThe git account used to access private repos. Passing empty string can only clone public repos.
Note. A token for the account must be available in the core config or the builder server’s periphery config for the configured git provider.
repo: StringThe repo used as the source of the build.
branch: StringThe branch of the repo.
commit: StringOptionally set a specific commit hash.
webhook_enabled: boolWhether incoming webhooks actually trigger action.
webhook_secret: StringOptionally provide an alternate webhook secret for this build. If its an empty string, use the default secret from the config.
pre_build: SystemCommandThe optional command run after repo clone and before docker build.
image_registry: ImageRegistryConfiguration for the registry to push the built image to.
build_path: StringThe path of the docker build context relative to the root of the repo. Default: “.” (the root of the repo).
dockerfile_path: StringThe path of the dockerfile relative to the build path.
skip_secret_interp: boolWhether to skip secret interpolation in the build_args.
use_buildx: boolWhether to use buildx to build (eg docker buildx build ...)
extra_args: Vec<String>Any extra docker cli arguments to be included in the build command
build_args: Vec<EnvironmentVar>Docker build arguments.
These values are visible in the final image by running docker inspect.
secret_args: Vec<EnvironmentVar>Secret arguments.
These values remain hidden in the final image by using
docker secret mounts. See <https://docs.docker.com/build/building/secrets>.
The values can be used in RUN commands:
RUN --mount=type=secret,id=SECRET_KEY \
SECRET_KEY=$(cat /run/secrets/SECRET_KEY) ...labels: Vec<EnvironmentVar>Docker labels
Implementations
Sourceimpl BuildConfig
impl BuildConfig
pub fn builder() -> BuildConfigBuilder