pub struct HetznerServerTemplateConfig {Show 14 fields
pub image: String,
pub datacenter: HetznerDatacenter,
pub private_network_ids: Vec<I64>,
pub placement_group: I64,
pub enable_public_ipv4: bool,
pub enable_public_ipv6: bool,
pub firewall_ids: Vec<I64>,
pub server_type: HetznerServerType,
pub ssh_keys: Vec<String>,
pub user_data: String,
pub use_public_ip: bool,
pub labels: HashMap<String, String>,
pub volumes: Vec<HetznerVolumeSpecs>,
pub port: i32,
}Expand description
Hetzner server config.
Fields
image: StringID or name of the Image the Server is created from
datacenter: HetznerDatacenterID or name of Datacenter to create Server in
private_network_ids: Vec<I64>Network IDs which should be attached to the Server private network interface at the creation time
placement_group: I64ID of the Placement Group the server should be in, Or 0 to not use placement group.
enable_public_ipv4: boolAttach an IPv4 on the public NIC. If false, no IPv4 address will be attached.
enable_public_ipv6: boolAttach an IPv6 on the public NIC. If false, no IPv6 address will be attached.
firewall_ids: Vec<I64>The firewalls to attach to the instance
server_type: HetznerServerTypeID or name of the Server type this Server should be created with
ssh_keys: Vec<String>SSH key IDs ( integer ) or names ( string ) which should be injected into the Server at creation time
user_data: StringCloud-Init user data to use during Server creation. This field is limited to 32KiB.
use_public_ip: boolConnect to the instance using it’s public ip.
labels: HashMap<String, String>Labels for the server
volumes: Vec<HetznerVolumeSpecs>Specs for volumes to attach
port: i32The port periphery will be running on in AMI.
Default: 8120
Implementations