pub struct ResourceSyncConfigBuilder { /* private fields */ }Expand description
Builder for ResourceSyncConfig.
Implementations
Sourceimpl ResourceSyncConfigBuilder
impl ResourceSyncConfigBuilder
Sourcepub fn git_provider(&mut self, value: String) -> &mut Self
pub fn git_provider(&mut self, value: String) -> &mut Self
The git provider domain. Default: github.com
Sourcepub fn git_https(&mut self, value: bool) -> &mut Self
pub fn git_https(&mut self, value: bool) -> &mut Self
Whether to use https to clone the repo (versus http). Default: true
Note. Monitor does not currently support cloning repos via ssh.
Sourcepub fn repo(&mut self, value: String) -> &mut Self
pub fn repo(&mut self, value: String) -> &mut Self
The Github repo used as the source of the build.
Sourcepub fn git_account(&mut self, value: String) -> &mut Self
pub fn git_account(&mut self, value: String) -> &mut Self
The git account used to access private repos. Passing empty string can only clone public repos.
Note. A token for the account must be available in the core config or the builder server’s periphery config for the configured git provider.
Sourcepub fn resource_path(&mut self, value: String) -> &mut Self
pub fn resource_path(&mut self, value: String) -> &mut Self
The path of the resource file(s) to sync, relative to the repo root.
Can be a specific file, or a directory containing multiple files / folders.
See https://docs.monitor.dev/docs/sync-resources for more information.
Sourcepub fn delete(&mut self, value: bool) -> &mut Self
pub fn delete(&mut self, value: bool) -> &mut Self
Whether sync should delete resources not declared in the resource files
Sourcepub fn webhook_enabled(&mut self, value: bool) -> &mut Self
pub fn webhook_enabled(&mut self, value: bool) -> &mut Self
Whether incoming webhooks actually trigger action.
Sourcepub fn webhook_secret(&mut self, value: String) -> &mut Self
pub fn webhook_secret(&mut self, value: String) -> &mut Self
Optionally provide an alternate webhook secret for this sync. If its an empty string, use the default secret from the config.
Sourcepub fn build(
&self,
) -> Result<ResourceSyncConfig, ResourceSyncConfigBuilderError>
pub fn build( &self, ) -> Result<ResourceSyncConfig, ResourceSyncConfigBuilderError>