pub struct StackConfig {Show 22 fields
pub server_id: String,
pub project_name: String,
pub run_directory: String,
pub file_paths: Vec<String>,
pub files_on_host: bool,
pub registry_provider: String,
pub registry_account: String,
pub extra_args: Vec<String>,
pub environment: Vec<EnvironmentVar>,
pub env_file_path: String,
pub skip_secret_interp: bool,
pub file_contents: String,
pub ignore_services: Vec<String>,
pub git_provider: String,
pub git_https: bool,
pub git_account: String,
pub repo: String,
pub branch: String,
pub commit: String,
pub webhook_enabled: bool,
pub webhook_secret: String,
pub send_alerts: bool,
}Expand description
The compose file configuration.
Fields
server_id: StringThe server to deploy the stack on.
project_name: StringOptionally specify a custom project name for the stack.
If this is empty string, it will default to the stack name.
Used with docker compose -p {project_name}.
Note. Can be used to import pre-existing stacks.
run_directory: StringDirectory to change to (cd) before running docker compose up -d.
Default: ./ (the repo root)
file_paths: Vec<String>Add paths to compose files, relative to the run path.
If this is empty, will use file compose.yaml.
files_on_host: boolIf this is checked, the stack will source the files on the host.
Use run_directory and file_paths to specify the path on the host.
This is useful for those who wish to setup their files on the host using SSH or similar,
rather than defining the contents in UI or in a git repo.
registry_provider: StringUsed with registry_account to login to a registry before docker compose up.
registry_account: StringUsed with registry_provider to login to a registry before docker compose up.
extra_args: Vec<String>The extra arguments to pass after docker compose up -d.
If empty, no extra arguments will be passed.
environment: Vec<EnvironmentVar>The environment variables passed to the compose file. They will be written to path defined in env_file_path, which is given relative to the run directory.
If it is empty, no file will be written.
env_file_path: StringThe name of the written environment file before docker compose up.
Relative to the repo root.
Default: .env
skip_secret_interp: boolWhether to skip secret interpolation into the stack environment variables.
file_contents: StringThe contents of the file directly, for management in the UI. If this is empty, it will fall back to checking git config for repo based compose file.
ignore_services: Vec<String>Ignore certain services declared in the compose file when checking
the stack status. For example, an init service might be exited, but the
stack should be healthy. This init service should be in ignore_services
git_provider: StringThe git provider domain. Default: github.com
git_https: boolWhether to use https to clone the repo (versus http). Default: true
Note. Monitor does not currently support cloning repos via ssh.
git_account: StringThe git account used to access private repos. Passing empty string can only clone public repos.
Note. A token for the account must be available in the core config or the builder server’s periphery config for the configured git provider.
repo: StringThe Github repo used as the source of the build.
branch: StringThe branch of the repo.
commit: StringOptionally set a specific commit hash.
webhook_enabled: boolWhether incoming webhooks actually trigger action.
webhook_secret: StringOptionally provide an alternate webhook secret for this stack. If its an empty string, use the default secret from the config.
send_alerts: boolWhether to send StackStateChange alerts for this stack.
Implementations
Sourceimpl StackConfig
impl StackConfig
pub fn builder() -> StackConfigBuilder